16.136. cdist-type__pyvenv(7) — cdist 6.9.8 documentation

# 16.136. cdist-type__pyvenv(7)

## 16.136.1. NAME

cdist-type__pyvenv - Create or remove python virtual environment

## 16.136.2. DESCRIPTION

This cdist type allows you to create or remove python virtual environment using pyvenv on python3 -m venv. It assumes pyvenv is already installed. Concrete package depends on concrete OS and/or OS version/distribution. Ensure this for e.g. in your init manifest as in the following example:

## 16.136.3. REQUIRED PARAMETERS

None

## 16.136.4. OPTIONAL PARAMETERS

state

  Either "present" or "absent", defaults to "present"

group

  Group to chgrp to

mode

  Unix permissions, suitable for chmod

owner

  User to chown to

pyvenv

  Use this specific pyvenv

venvparams

  Specific parameters to pass to pyvenv invocation

## 16.136.5. EXAMPLES

    __pyvenv /home/services/djangoenv

    # Use specific pyvenv
    __pyvenv /home/foo/fooenv --pyvenv /usr/local/bin/pyvenv-3.4

    # Create python virtualenv for user foo.
    __pyvenv /home/foo/fooenv --group foo --owner foo

    # Create python virtualenv with specific parameters.
    __pyvenv /home/services/djangoenv --venvparams "--copies --system-site-packages"

## 16.136.6. AUTHORS

Darko Poljak <darko.poljak--@--gmail.com>

## 16.136.7. COPYING

Copyright (C) 2016 Darko Poljak. Free use of this software is granted under the terms of the GNU General Public License v3 or later (GPLv3+).